Index: fetch_configs/webrtc_android.py |
diff --git a/recipes/webrtc_android.py b/fetch_configs/webrtc_android.py |
similarity index 78% |
rename from recipes/webrtc_android.py |
rename to fetch_configs/webrtc_android.py |
index 6d6018a86c9e21863d838a770483180ae3667deb..5b53235d613787aedacee4e143409eed7bc3c528 100644 |
--- a/recipes/webrtc_android.py |
+++ b/fetch_configs/webrtc_android.py |
@@ -4,19 +4,19 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class WebRTCAndroid(recipe_util.Recipe): |
- """Basic Recipe alias for Android -> WebRTC.""" |
+class WebRTCAndroid(config_util.Config): |
+ """Basic Config alias for Android -> WebRTC.""" |
@staticmethod |
def fetch_spec(props): |
return { |
'alias': { |
- 'recipe': 'webrtc', |
+ 'config': 'webrtc', |
'props': ['--target_os=android,unix'], |
}, |
} |